import logging  # noqa: INP001
import sqlite3

from .table import QolsysTable

LOGGER = logging.getLogger(__name__)


class QolsysTableMasterSlave(QolsysTable):

    def __init__(self, db: sqlite3.Connection, cursor: sqlite3.Cursor) -> None:
        super().__init__(db, cursor)
        self._uri = "content://com.qolsys.qolsysprovider.MasterSlaveContentProvider/master_slave"
        self._table = "master_slave"
        self._abort_on_error = False
        self._implemented = True

        self._columns = [
            "_id",
            "version",
            "opr",
            "partition_id",
            "zone_id",
            "ip_address",
            "mac_address",
            "device_type",
            "created_by",
            "created_date",
            "updated_by",
            "last_updated_date",
            "status",
            "device_name",
            "last_updated_iq_remote_checksum",
            "software_version",
            "upgrade_status",
            "name",
            "bssid",
            "ssid",
            "dhcpInfo",
            "topology",
            "reboot_reason",
            "field_remote_camera_streaming",
        ]

        self._create_table()



import logging  # noqa: INP001
import sqlite3

from .table import QolsysTable

LOGGER = logging.getLogger(__name__)


class QolsysTableWeather(QolsysTable):

    def __init__(self, db: sqlite3.Connection, cursor: sqlite3.Cursor) -> None:
        super().__init__(db, cursor)
        self._uri = "content://com.qolsys.qolsysprovider.ForecastWeatherContentProvider/weather"
        self._table = "weather"
        self._abort_on_error = True
        self._implemented = True

        self._columns = [
            "_id",
            "version",
            "opr",
            "partition_id",
            "high_temp",
            "low_temp",
            "day_of_week",
            "condition",
            "icon",
            "precipitation",
            "current_weather_date",
        ]

        self._create_table()




import logging  # noqa: INP001
import sqlite3

from .table import QolsysTable

LOGGER = logging.getLogger(__name__)


class QolsysTableScene(QolsysTable):

    def __init__(self, db: sqlite3.Connection, cursor: sqlite3.Cursor) -> None:
        super().__init__(db, cursor)
        self._uri = "content://com.qolsys.qolsysprovider.SceneContentProvider/scene"
        self._table = "scene"
        self._abort_on_error = False
        self._implemented = True


        self._columns = [
            "_id",
            "version",
            "opr",
            "partition_id",
            "scene_id",
            "name",
            "icon",
            "color",
            "flags",
            "ack",
            "create_time",
            "created_by",
            "update_time",
            "updated_by",
        ]

        self._create_table()



import logging  # noqa: INP001
import sqlite3

from .table import QolsysTable

LOGGER = logging.getLogger(__name__)


class QolsysTableDashboardMsgs(QolsysTable):

    def __init__(self, db: sqlite3.Connection, cursor: sqlite3.Cursor) -> None:
        super().__init__(db, cursor)
        self._uri = "content://com.qolsys.qolsysprovider.DashboardMessagesContentProvider/dashboard_msgs"
        self._table = "dashboard_msgs"
        self._abort_on_error = False
        self._implemented = True


        self._columns = [
            "_id",
            "version",
            "opr",
            "partition_id",
            "msg_id",
            "title",
            "description",
            "received_time",
            "start_time",
            "end_time",
            "read",
            "mime_type",
        ]

        self._create_table()
